@@ -26,11 +26,9 @@
 #include <set>
 #include <string>
 #include <vector>
+#include <sys/stat.h>
 #include <time.h>
 
-#include <zlib.h>
-
-
 /* Define this for python-apt */
 #define APT_HAS_GZIP 1
 
