@@ -12,6 +12,7 @@
 
 #include <apt-pkg/fileutl.h>
 #include <apt-pkg/srcrecords.h>
+#include <apt-pkg/tagfile-keys.h>
 #include <apt-pkg/tagfile.h>
 
 #include <string>
@@ -40,9 +41,9 @@ class APT_HIDDEN debSrcRecordParser : public pkgSrcRecords::Parser
    virtual bool Jump(unsigned long const &Off) APT_OVERRIDE {iOffset = Off; return Tags.Jump(Sect,Off);};
 
    virtual std::string Package() const APT_OVERRIDE;
-   virtual std::string Version() const APT_OVERRIDE {return Sect.FindS("Version");};
-   virtual std::string Maintainer() const APT_OVERRIDE {return Sect.FindS("Maintainer");};
-   virtual std::string Section() const APT_OVERRIDE {return Sect.FindS("Section");};
+   virtual std::string Version() const APT_OVERRIDE {return Sect.Find(pkgTagSection::Key::Version).to_string();};
+   virtual std::string Maintainer() const APT_OVERRIDE {return Sect.Find(pkgTagSection::Key::Maintainer).to_string();};
+   virtual std::string Section() const APT_OVERRIDE {return Sect.Find(pkgTagSection::Key::Section).to_string();};
    virtual const char **Binaries() APT_OVERRIDE;
    virtual bool BuildDepends(std::vector<BuildDepRec> &BuildDeps, bool const &ArchOnly, bool const &StripMultiArch = true) APT_OVERRIDE;
    virtual unsigned long Offset() APT_OVERRIDE {return iOffset;};
