@@ -33,7 +33,7 @@
 // ---------------------------------------------------------------------
 /* */
 AcqTextStatus::AcqTextStatus(std::ostream &out, unsigned int &ScreenWidth,unsigned int const Quiet) :
-    pkgAcquireStatus2(), out(out), ScreenWidth(ScreenWidth), LastLineLength(0), ID(0), Quiet(Quiet)
+    pkgAcquireStatus(), out(out), ScreenWidth(ScreenWidth), LastLineLength(0), ID(0), Quiet(Quiet)
 {
    // testcases use it to disable pulses without disabling other user messages
    if (Quiet == 0 && _config->FindB("quiet::NoUpdate", false) == true)
@@ -221,21 +221,21 @@ bool AcqTextStatus::Pulse(pkgAcquire *Owner)
 	 enum {Long = 0,Medium,Short} Mode = Medium;
 	 // Add the current progress
 	 if (Mode == Long)
-	    S << " " << std::to_string(I->CurrentSize);
+	    S << " " << std::to_string(I->CurrentItem->CurrentSize);
 	 else
 	 {
-	    if (Mode == Medium || I->TotalSize == 0)
-	       S << " " << SizeToStr(I->CurrentSize) << "B";
+	    if (Mode == Medium || I->CurrentItem->TotalSize == 0)
+	       S << " " << SizeToStr(I->CurrentItem->CurrentSize) << "B";
 	 }
 
 	 // Add the total size and percent
-	 if (I->TotalSize > 0 && I->CurrentItem->Owner->Complete == false)
+	 if (I->CurrentItem->TotalSize > 0 && I->CurrentItem->Owner->Complete == false)
 	 {
 	    if (Mode == Short)
-	       ioprintf(S, " %.0f%%", (I->CurrentSize*100.0)/I->TotalSize);
+	       ioprintf(S, " %.0f%%", (I->CurrentItem->CurrentSize*100.0)/I->CurrentItem->TotalSize);
 	    else
-	       ioprintf(S, "/%sB %.0f%%", SizeToStr(I->TotalSize).c_str(),
-		     (I->CurrentSize*100.0)/I->TotalSize);
+	       ioprintf(S, "/%sB %.0f%%", SizeToStr(I->CurrentItem->TotalSize).c_str(),
+		     (I->CurrentItem->CurrentSize*100.0)/I->CurrentItem->TotalSize);
 	 }
 	 S << "]";
       }
@@ -337,10 +337,10 @@ bool AcqTextStatus::ReleaseInfoChanges(metaIndex const * const L, metaIndex cons
 {
    if (Quiet >= 2 || isatty(STDOUT_FILENO) != 1 || isatty(STDIN_FILENO) != 1 ||
 	 _config->FindB("APT::Get::Update::InteractiveReleaseInfoChanges", false) == false)
-      return pkgAcquireStatus2::ReleaseInfoChanges(nullptr, nullptr, std::move(Changes));
+      return pkgAcquireStatus::ReleaseInfoChanges(nullptr, nullptr, std::move(Changes));
 
    _error->PushToStack();
-   auto const confirmed = pkgAcquireStatus2::ReleaseInfoChanges(L, N, std::move(Changes));
+   auto const confirmed = pkgAcquireStatus::ReleaseInfoChanges(L, N, std::move(Changes));
    if (confirmed == true)
    {
       _error->MergeWithStack();
